#!/bin/bash
#
# author           : Markus Muttilainen (stillborn.zenwalk@gmail.com)
# project web page : http://goodies.xfce.org/projects/panel-plugins/xfce4-cpufreq-plugin
(
# Package name
NAME="xfce4-cpu-freq-plugin"
# Package version
VERSION="0.0.1"
# Source code URL
SOURCE="http://goodies.xfce.org/releases/xfce4-cpufreq-plugin/xfce4-cpufreq-plugin-$VERSION.tar.gz"
SOURCEFILE=`echo -n $SOURCE | sed -e "s,.*/,,"`
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS COPYING ChangeLog INSTALL NEWS README"
# ./configure options
CONFIGOPTIONS="--prefix=/usr"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="64.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: xfce4-cpufreq-plugin shows info about CPU frequency in xfce panel
$NAME:
$NAME: The CpuFreq Plugin shows in the Xfce Panel the following,
$NAME: chooseable informations: current CPU frequency and current used
$NAME: governor. In a seperate dialog it provides you following
$NAME: informations of all available informations: all available CPU
$NAME: frequencies, all available governors and used driver for the cpu.
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $SOURCEFILE ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if icons are present. If it's not, download it
if [ -f icons.tar.gz ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://zenwalk.pinguix.com/user-accounts/stillborn/xfce4-cpu-freq-plugin-0.0.1/icons.tar.gz
fi

# Unpack source
tar xvf $SOURCEFILE
tar xvf icons.tar.gz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure $CONFIGOPTIONS
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Remove broken stock icons and install right new ones
rm -rf $PKG/usr/share/icons/hicolor
ICONSIZES="48 32 24 22 16"
for i in $ICONSIZES; do
	mkdir -p $PKG/usr/share/icons/hicolor/$i\x$i/apps;
	mv $CWD/cpu-$i.png $PKG/usr/share/icons/hicolor/$i\x$i/apps/$NAME.png;
done;
mkdir -p $PKG/usr/share/icons/hicolor/scalable/apps
mv $CWD/cpu.svg $PKG/usr/share/icons/hicolor/scalable/apps

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.txz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.txz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
) 2>&1 | tee build-xfce4-cpu-freq-plugin.log.txt
